#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pipes
version:              4.3.16
visibility:           public
id:                   pipes-4.3.16-5gG7CXwJIY73d2rfmtnGG
key:                  pipes-4.3.16-5gG7CXwJIY73d2rfmtnGG
license:              BSD-3-Clause
copyright:            2012-2016 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             Compositional pipelines
description:
    `pipes` is a clean and powerful stream processing library that lets you build
    and connect reusable streaming components

    Advantages over traditional streaming libraries:

    * /Concise API/: Use simple commands like '\''for'\'', ('\''>->'\''), '\''await'\'', and '\''yield'\''

    * /Blazing fast/: Implementation tuned for speed, including shortcut fusion

    * /Lightweight Dependency/: @pipes@ is small and compiles very rapidly,
    including dependencies

    * /Elegant semantics/: Use practical category theory

    * /ListT/: Correct implementation of '\''ListT'\'' that interconverts with pipes

    * /Bidirectionality/: Implement duplex channels

    * /Extensive Documentation/: Second to none!

    Import "Pipes" to use the library.

    Read "Pipes.Tutorial" for an extensive tutorial.

category:             Control, Pipes
abi:                  6523bcbcd086580791ff883a4bd2395d
exposed:              True
exposed-modules:
    Pipes Pipes.Core Pipes.Internal Pipes.Lift Pipes.Prelude
    Pipes.Tutorial

import-dirs:          /usr/lib/ghc-9.6.6/site-local/pipes-4.3.16
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pipes-4.3.16
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pipes-4.3.16
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pipes
hs-libraries:         HSpipes-4.3.16-5gG7CXwJIY73d2rfmtnGG
depends:
    base-4.18.2.1 exceptions-0.10.7 mmorph-1.2.2-I879kMQXeoiA7V1mSxl9UH
    mtl-2.3.1 transformers-0.6.1.0 void-0.7.4-Ab78HEYVlxC2PerDGXO6Wd

haddock-interfaces:   /usr/share/doc/haskell-pipes/html/pipes.haddock
haddock-html:         /usr/share/doc/haskell-pipes/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

